Class: Dalli::Elasticache::AutoDiscovery::ConfigCommand
- Inherits:
-
BaseCommand
- Object
- BaseCommand
- Dalli::Elasticache::AutoDiscovery::ConfigCommand
- Defined in:
- lib/dalli/elasticache/auto_discovery/config_command.rb
Overview
Encapsulates execution of the ‘config’ command, which is used to extract the list of nodes and determine if that list of nodes has changed.
Constant Summary collapse
- CONFIG_COMMAND =
"config get cluster\r\n"
Instance Attribute Summary
Attributes inherited from BaseCommand
Instance Method Summary collapse
Methods inherited from BaseCommand
#initialize, #response_from_socket, #send_command
Constructor Details
This class inherits a constructor from Dalli::Elasticache::AutoDiscovery::BaseCommand
Instance Method Details
#command ⇒ Object
17 18 19 |
# File 'lib/dalli/elasticache/auto_discovery/config_command.rb', line 17 def command CONFIG_COMMAND end |
#response ⇒ Object
13 14 15 |
# File 'lib/dalli/elasticache/auto_discovery/config_command.rb', line 13 def response ConfigResponse.new(send_command) end |